window.clickableEditor = {};

jQuery(document).ready(function($) {
	/********************************************
	 * Update editor to use align= as alignment *
	 ********************************************/
	$.sceditorBBCodePlugin.setCommand("align", { }, null, "handed by default align commands", function(element, attrs, content) {
		var align = 'left';

		if(attrs.defaultattr)
			align = attrs.defaultattr;

		return '<div align="' + align + '">' + content + '</div>';
	}, false, true);
	$.sceditorBBCodePlugin.setCommand("center",	null, null, "[align=center]{0}[/align]",	'<div align="center">{0}</div>');
	$.sceditorBBCodePlugin.setCommand("left",	null, null, "[align=left]{0}[/align]",		'<div align="left">{0}</div>');
	$.sceditorBBCodePlugin.setCommand("right",	null, null, "[align=right]{0}[/align]",		'<div align="right">{0}</div>');
	$.sceditorBBCodePlugin.setCommand("justify",	null, null, "[align=justify]{0}[/align]",	'<div align="justify">{0}</div>');



	/********************************************
	 * Update quote to support pid and dateline *
	 ********************************************/
	$.sceditorBBCodePlugin.setCommand("quote", null, null, function(element, content) {
		var	author,
			attr = '',
			$elm = $(element);

		if($elm.children("cite:first").length === 1 || $elm.data("author")) {
			author = $(element).children("cite:first").text() || $elm.data("author");

			
			$elm.data("author", author)
			$(element).children("cite:first").remove();

			content	= '';
			content	= this.elementToBbcode($(element));
			attr	= '=' + author;
		}

		if($(element).data('pid'))
			attr += " pid='"+$(element).data('pid')+"'";

		if($(element).data('dateline'))
			attr += " dateline='"+$(element).data('dateline')+"'";

		return '[quote' + attr + ']' + content + '[/quote]';
	},function(element, attrs, content) {
		var data = '';

		if(attrs.pid)
			data += ' data-pid="' + attrs.pid + '"';

		if(attrs.dateline)
			data += ' data-dateline="' + attrs.dateline + '"';

		if(attrs.defaultattr)
			content = '<cite>' + attrs.defaultattr + '</cite>' + content;

		return '<blockquote' + data + '>' + content + '</blockquote>';
	});



	/*************************************
	 * Remove last bits of table support *
	 *************************************/
	delete $.sceditorBBCodePlugin.bbcodes.table;
	delete $.sceditorBBCodePlugin.bbcodes.tr;
	delete $.sceditorBBCodePlugin.bbcodes.th;
	delete $.sceditorBBCodePlugin.bbcodes.td;
	delete $.sceditor.commands.table;


	/*******************
	 * Init the editor *
	 *******************/
	$("#message, #signature").sceditorBBCodePlugin({
		style:			"jscripts/sceditor/jquery.sceditor.mybb.css",
		toolbar:		"bold,italic,underline,strike,subscript,superscript|left,center,right,justify|" +
					"font,size,color,removeformat|cut,copy,paste,pastetext|bulletlist,orderedlist|" +
					"code,quote|horizontalrule,image,email,link,unlink|emoticon,youtube,date,time|" +
					"print,source",
		resizeMaxHeight:	800,
		autofocus:		sceditor_autofocus,
		emoticons:		mybb_emoticons
	});


	/**************************
	 * Emoticon click support *
	 **************************/
	$("#clickable_smilies img").each(function() {
		$(this).css('cursor', 'pointer');

		$(this).click(function() {
			var alt		= $(this).attr("alt");
			var html	= '<img src="' + $(this).attr("src") + '" data-sceditor-emoticon="' + alt + '" alt="' + alt + '" />';

			$("#message, #signature").data("sceditor").wysiwygEditorInsertHtml(html);
		});
	});



	/************************************
	 * clickableEditor compat functions *
	 ************************************/
	clickableEditor.insertAttachment = function(aid) {
		$("#message, #signature").data("sceditor").insertText('[attachment='+aid+']');
	};

	clickableEditor.performInsert = function(code, src) {
		var html = '<img src="' + src + '" data-sceditor-emoticon="' + code + '" alt="' + code + '" />';
		$("#message, #signature").data("sceditor").wysiwygEditorInsertHtml(html);
	};

	clickableEditor.openGetMoreSmilies = function(editor)
	{
		MyBB.popupWindow('misc.php?action=smilies&popup=true&editor='+editor, 'sminsert', 240, 280);
	};



	/****************************
	 * Form reset compatibility *
	 ****************************/
	var textarea = $("#message, #signature").get(0);
	if(textarea)
	{
		$(textarea.form).bind("reset", function() {
			$("#message, #signature").data("sceditor").val("");
		});
	}
});

/**********************************
 * Thread compatibility functions *
 **********************************/
if(Thread)
{
	var quickReplyFunc = Thread.quickReply;
	// update the textarea to the editors value before the Thread class
	// uses it for quickReply, ect.
	Thread.quickReply = function(e) {
		var editor = jQuery("#message, #signature").data("sceditor");

		if(editor)
			editor.updateTextareaValue();

		return quickReplyFunc.call(Thread, e);
	};

	Thread.multiQuotedLoaded = function(request)
	{
		if(request.responseText.match(/<error>(.*)<\/error>/))
		{
			message = request.responseText.match(/<error>(.*)<\/error>/);
			if(!message[1])
				message[1] = "An unknown error occurred.";

			if(this.spinner)
			{
				this.spinner.destroy();
				this.spinner = '';
			}

			alert('There was an error fetching the posts.\n\n'+message[1]);
		}
		else if(request.responseText)
		{
			var editor = jQuery("#message, #signature").data("sceditor");

			if(editor)
				editor.insert(request.responseText);
		}

		Thread.clearMultiQuoted();
		$('quickreply_multiquote').hide();
		$('quoted_ids').value = 'all';

		if(this.spinner)
		{
			this.spinner.destroy();
			this.spinner = '';
		}
	};
}
